This is a wrapper function used by explore_space_pca() and
should be be called directly by the user
add_anno(dt, anno_color = "black", anno_lty = "dashed", anno_alpha = 0.1, ...)a wrapper for annotating the symmetry of start points in explore_space_pca()
A data object from the running the optimisation algorithm in guided tour
character; the colour of the annotation line
character; the linetype of the annotation line
numeric; the alpha of the annotation line
other aesthetics inherent from explore_space_pca()
Other draw functions:
add_anchor(),
add_dir_search(),
add_end(),
add_interp(),
add_interp_last(),
add_interrupt(),
add_search(),
add_space(),
add_start(),
add_theo()